@@ -6,8 +6,7 @@ from requests.auth import HTTPBasicAuth
 from urllib3 import disable_warnings
 from urllib3.exceptions import InsecureRequestWarning
 from zeep.cache import SqliteCache
-from zeep.settings import Settings
-import configparser
+import jabberwock
 
 
 class AXLClient(Client):
@@ -19,32 +18,25 @@ class AXLClient(Client):
     clients = dict()
     BINDING_NAME = "{http://www.cisco.com/AXLAPIService/}AXLAPIBinding"
 
-    def __init__(self, config_name='default', toolkit_path='/axlsqltoolkit', **kwargs):
+    def __init__(self, config_name='default', **kwargs):
         """
         Args:
             config_name: the name of the config file
         """
-        self.config = configparser.ConfigParser()
-        self.config.read('{toolkit_path}/config/{config_name}.ini'.format(toolkit_path=toolkit_path,
-                                                                          config_name=config_name))
-        username = self.config['authentication']['username']
-        password = self.config['authentication']['password']
-        version = self.config['authentication']['version']
+        self.config = jabberwock.configuration.registry.get(config_name)
         disable_warnings(InsecureRequestWarning)
-        settings = Settings(strict=False, xml_huge_tree=True)
-        wsdl = 'file://' + toolkit_path + '/schema/' + version + '/AXLAPI.wsdl'
+        wsdl = 'file://' + self.config.schema_path + '/' + self.config.version + '/AXLAPI.wsdl'
         session = Session()
         session.verify = False
-        session.auth = HTTPBasicAuth(username, password)
-        transport = Transport(cache=SqliteCache(), session=session, timeout=20)
-        defaults = dict(wsdl=wsdl, transport=transport, plugins=[HistoryPlugin()], settings=settings)
+        session.auth = HTTPBasicAuth(self.config.username, self.config.password)
+        transport = Transport(cache=SqliteCache(), session=session, timeout=60)
+        defaults = dict(wsdl=wsdl, transport=transport, plugins=[HistoryPlugin()], settings=self.config.zeep_settings)
         merged_kwargs = {**defaults, **kwargs}
         super().__init__(**merged_kwargs)
 
     @property
     def axl(self):
-        server = self.config['authentication']['server']
-        address = "https://{server}:8443/axl/".format(server=server)
+        address = "https://{host}:8443/axl/".format(host=self.config.host)
         return self.create_service(self.BINDING_NAME, address)
 
     @property
@@ -52,12 +44,12 @@ class AXLClient(Client):
         return self.type_factory('ns0')
 
     @classmethod
-    def get_client(cls, config_name='default', toolkit_path='/axlsqltoolkit', recreate=False):
+    def get_client(cls, config_name='default', recreate=False):
         """ return a single instance of client for each configuration.
         """
         client = None
         if config_name not in cls.clients or recreate:
-            client = AXLClient(config_name, toolkit_path)
+            client = AXLClient(config_name)
         return cls.clients.setdefault(config_name, client)
 
 
